import { Injectable, Inject } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';

import { Observable } from 'rxjs';
import { map, takeUntil } from 'rxjs/operators';
import { API_BASE_URL } from 'src/modules/common/type/injection-token.type';
import { Page } from 'src/modules/common/data/model/page';
import { FormArray } from '@angular/forms';

import { UserDateAuditEntity } from 'src/modules/common/data/model/audit';

import { FreeBoard } from '../model/free-board.model';

@Injectable({
  providedIn: 'root'
})
export class FreeBoardService {
  constructor(
    @Inject(API_BASE_URL) private apiBaseUrl: string,
    private httpClient: HttpClient
  ) {}

  public regist(freeBoard: FreeBoard): Observable<any> {
    // const engName = freeBoard.attachFile;
    const title = freeBoard.title;
    const contents = freeBoard.contents;
    const owner = 1;
    return this.httpClient
      .post<any>(`${this.apiBaseUrl}/free-board`, {
        title,
        contents,
        owner
      })
      .pipe(
        map(res => {
          console.log('free board regist response: ' + res);
          return res;
        })
      );
  }

  public modify(freeBoard: FreeBoard): Observable<any> {
    const id = freeBoard.id;
    const title = freeBoard.title;
    const contents = freeBoard.contents;
    const createdBy = freeBoard.createdBy;
    const owner = 1;
    return this.httpClient
      .put<any>(`${this.apiBaseUrl}/free-board/${id}`, {
        id,
        title,
        contents,
        owner,
        createdBy
      })
      .pipe(
        map(res => {
          console.log('free board modify response: ' + res);
          return res;
        })
      );
  }

  public getById(boardId: number): Observable<FreeBoard> {
    return this.httpClient.get<FreeBoard>(
      `${this.apiBaseUrl}/free-board/${boardId}`,
      {}
    );
  }
  public getAll(): Observable<Page<FreeBoard>> {
    return this.httpClient.get<Page<FreeBoard>>(
      `${this.apiBaseUrl}/free-board`,
      {}
    );
  }

  public removeById(boardId: number): Observable<any> {
    const id = boardId;
    return this.httpClient
      .delete<any>(`${this.apiBaseUrl}/free-board/${boardId}`, {})
      .pipe(
        map(res => {
          console.log('free board modify response: ' + res);
          return res;
        })
      );
  }
}
